"""Package watermark.py

A convinient python library to apply watermarks to images, gifs and videos.

MIT License

Copyright (c) 2021 Aahnik Daw

https://github.com/aahnik/watermark.py
"""

from importlib.metadata import version

__version__ = version(__package__)



import logging

from PIL import Image

def to_png(file: str) -> str:
    im = Image.open(file)
    if not file.endswith(".png"):
        png_file = f"{file}.png"
        im.save(png_file)
    else:
        png_file = file

    return png_file


def _open_image(file: str):
    im = Image.open(file)
    logging.info(
        f"""Opened Image {file}
        Image format {im.format}
        Mode {im.mode}
        Size {im.size}
            Height {im.height}
            Width {im.width}
    """
    )
    im = im.convert("RGBA")

    return im


def watermark_image(image_file: str, watermark_file: str = "image.png",x_off=10,y_off=10):
    png = to_png(image_file)
    im = _open_image(png)
    wt = _open_image(watermark_file)
    im.alpha_composite(im=wt, dest=(x_off,y_off))
    output_file = f"watered_{png}"
    im.save(output_file)
    cleanup(png)
    return output_file


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['watermark_py']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'watermark.py',
    'version': '0.0.1rc0',
    'description': 'A convinient python library to apply watermarks to images, gifs and videos.',
    'long_description': '# watermark.py\n\nA convinient python library to apply watermarks to images, gifs and videos.\n\n## Installation\n\n```shell\npip install watermark.py\n```\n\n## Dependancies\n\nYou need to install these seperately.\n\n- `ffmpeg` for watermarking videos.\n- `Pillow` for watermarking images.\n\n## Usage\n\n```python\nfrom watermark_py import File,Watermark\n\nfile = File("path to file")\nwatermark = Watermark("path to image",x_off,y_off)\n\nfile.apply(watermark)\n```\n\n## Used by\n\n- tgcf\n- telewater\n',
    'author': 'aahnik',
    'author_email': 'daw@aahnik.dev',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/aahnik/watermark.py',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
